ports/113573: [PATCH] devel/cl-asdf: Respect LOCALBASE

Tim Bishop tdb at FreeBSD.org
Mon Jun 11 13:00:15 UTC 2007


>Number:         113573
>Category:       ports
>Synopsis:       [PATCH] devel/cl-asdf: Respect LOCALBASE
>Confidential:   no
>Severity:       non-critical
>Priority:       low
>Responsible:    freebsd-ports-bugs
>State:          open
>Quarter:        
>Keywords:       
>Date-Required:
>Class:          change-request
>Submitter-Id:   current-users
>Arrival-Date:   Mon Jun 11 13:00:14 GMT 2007
>Closed-Date:
>Last-Modified:
>Originator:     Tim Bishop
>Release:        FreeBSD 6.2-STABLE i386
>Organization:
>Environment:
System: FreeBSD pendennis.kent.ac.uk 6.2-STABLE FreeBSD 6.2-STABLE #4: Sun May 20 17:30:14 BST 2007
>Description:
Respect LOCALBASE.

I'm happy to commit this, but wanted to file it so I don't forget :-)

Generated with FreeBSD Port Tools 0.77
>How-To-Repeat:
>Fix:

--- cl-asdf-2003.05.16_1.patch begins here ---
Index: Makefile
===================================================================
RCS file: /u2/freebsd/cvs/ports/devel/cl-asdf/Makefile,v
retrieving revision 1.5
diff -u -r1.5 Makefile
--- Makefile	16 Oct 2005 14:48:05 -0000	1.5
+++ Makefile	11 Jun 2007 11:37:26 -0000
@@ -27,8 +27,10 @@
 	${MKDIR} ${ASDF_SYSTEM_REGISTRY}
 	${INSTALL_DATA} ${WRKSRC}/asdf.lisp ${CL_LIBDIR}/asdf/
 	${INSTALL_DATA} ${WRKSRC}/wild-modules.lisp ${CL_LIBDIR}/asdf/
+	${SED}	-i '' -e 's|%%PREFIX%%|${PREFIX}|' ${CL_LIBDIR}/asdf/asdf.lisp
 	${SED}	-e 's|%%ASDF_PATHNAME%%|${CL_LIBDIR}/asdf/asdf|' \
 		-e 's|%%ASDF_SYSTEM_REGISTRY%%|${ASDF_SYSTEM_REGISTRY}|' \
+		-e 's|%%PREFIX%%|${PREFIX}|' \
 		${FILESDIR}/asdf-init.lisp > \
 		${PREFIX}/etc/asdf-init.lisp.default
 	[ -f ${PREFIX}/etc/asdf-init.lisp ] || \
Index: files/patch-asdf.lisp
===================================================================
RCS file: /u2/freebsd/cvs/ports/devel/cl-asdf/files/patch-asdf.lisp,v
retrieving revision 1.1
diff -u -r1.1 patch-asdf.lisp
--- files/patch-asdf.lisp	3 Jun 2003 02:54:31 -0000	1.1
+++ files/patch-asdf.lisp	11 Jun 2007 11:19:33 -0000
@@ -6,7 +6,7 @@
    '(*default-pathname-defaults*
 -    #+nil "/home/dan/src/sourceforge/cclan/asdf/systems/"
 -    #+nil "telent:asdf;systems;"))
-+    "/usr/local/lib/common-lisp/system-registry/"))
++    "%%PREFIX%%/lib/common-lisp/system-registry/"))
  
  (defun sysdef-central-registry-search (system)
    (let ((name (coerce-name system)))
--- cl-asdf-2003.05.16_1.patch ends here ---

>Release-Note:
>Audit-Trail:
>Unformatted:



More information about the freebsd-ports-bugs mailing list
Index: files/asdf-init.lisp
===================================================================
RCS file: /u2/freebsd/cvs/ports/devel/cl-asdf/files/asdf-init.lisp,v
retrieving revision 1.1
diff -u -r1.1 asdf-init.lisp
--- files/asdf-init.lisp	3 Jun 2003 02:54:31 -0000	1.1
+++ files/asdf-init.lisp	11 Jun 2007 11:19:17 -0000
@@ -36,22 +36,22 @@
 ;; This file takes all neccessary actions. The easiest way is to load
 ;; it in your Lisp everytime it starts, by putting
 ;;
-;;  (load "/usr/local/etc/freebsd-lisp-init")
+;;  (load "%%PREFIX%%/etc/freebsd-lisp-init")
 ;;
 ;; in your init file.
 ;;
 ;; Each Lisp implementation has it's own files where this can be done:
 ;;
 ;; CLISP:
-;;   /usr/local/lib/clisp/config.lisp
+;;   %%PREFIX%%/lib/clisp/config.lisp
 ;;   ~/.clisprc
 ;;
 ;; CMUCL:
-;;   /usr/local/lib/cmucl/lib/cmucl/lib/site-init.lisp
+;;   %%PREFIX%%/lib/cmucl/lib/cmucl/lib/site-init.lisp
 ;;   ~/.cmucl-init.lisp
 ;;
 ;; SBCL:
-;;  /usr/local/etc/sbclrc
+;;  %%PREFIX%%/etc/sbclrc
 ;;  ~/.sbclrc
 ;;
 ;; After that, you can load your installed ports like this (using
@@ -68,7 +68,7 @@
 ;; We mess around with asdf:output-files in interesting ways to
 ;; enforce a filesystem layout that works without multiple Lisp
 ;; implementations overwriting their fasls. Basically, each lib has
 ;; it's own directory in /usr/local/lib/common-lisp, initially
 ;; containing its sources. Each fasl port will create an
 ;; implementation-specific subdirectory where all it's fasls go, for
 ;; example ./cmuclfasl, ./clispfasl etc.
@@ -126,11 +126,11 @@
 ;;;; Pathes
 
 (defvar *asdf-pathname*
-  "/usr/local/lib/common-lisp/asdf/asdf"
+  "%%PREFIX%%/lib/common-lisp/asdf/asdf"
   "Path of the ASDF library")
 
 (defvar *system-registry*
-  "/usr/local/lib/common-lisp/system-registry"
+  "%%PREFIX%%/lib/common-lisp/system-registry"
   "FreeBSDs contribution to the entral registry for ASDF system
 definitions.  This will be added to asdf:*central-registry*, you
 should modify that in order to add other directories.")
@@ -68,7 +68,7 @@
 ;; enforce a filesystem layout that works without multiple Lisp
 ;; implementations overwriting their fasls. Basically, each lib has
-;; it's own directory in /usr/local/lib/common-lisp, initially
+;; it's own directory in %%PREFIX%%/lib/common-lisp, initially
 ;; containing its sources. Each fasl port will create an
 ;; implementation-specific subdirectory where all it's fasls go, for